# argufy

[![npm version](https://badge.fury.io/js/argufy.svg)](https://npmjs.org/package/argufy)

```sh
yarn add -E argufy
```

`argufy` will parse command line arguments to Node.js CLI programs.

- [API](#api)
  * [`argufy(config: <string, ConfigItem>, argv?: string[]): object`](#argufyconfig-string-configitemargv-string-object)
    * [`_argv property`](#_argv-property)
  * [`ConfigItem` Type](#configitem-type)
    * [`Flag`](#type-flag)
- [Copyright](#copyright)

## API

The package is available by importing its default function:

```js
import argufy from 'argufy'
```

The package assumes that the arguments begin from the 3rd position, i.e.,

```sh
node example.js --title "Hello World"
```

### `argufy(`<br/>&nbsp;&nbsp;`config: <string, ConfigItem>,`<br/>&nbsp;&nbsp;`argv?: string[],`<br/>`): object`

The flags from the arguments will be extracted according to the configuration object and the arguments array. If arguments array is not passed, `process.argv` is used to find arguments.

```javascript
import argufy from 'argufy'

const config = {
  title: { short: 't', command: true },
  list: { short: 'l', boolean: true },
  app: 'a',
  delay: 'y',
  file: 'f',
  wait: { short: 'w', number: true },
  'no-empty': 'e',
  resize: 'z',
  colors: 'c',
  dir: 'D',
}

const res = argufy(config, process.argv)
console.log(JSON.stringify(res, null, 2))
```

```sh
node example.js --title Hello_World -w 10 -l -app Argufy
# or
node example.js Hello_World -w 10 -l -app Argufy
# no support "for arguments with space"
```

```json
{
  "_argv": [],
  "title": "Hello_World",
  "list": true,
  "app": "Argufy",
  "wait": 10
}
```

The special <a name="_argv-property">`_argv property`</a> will be assigned to contain all unmatched arguments. For example, it can be used to pass any additional parameters through to other program.

### `ConfigItem` Type

The configuration for each flag can either be a shorthand string, or an object. If it is an object, it can include the following parameters:

__<a name="type-flag">`Flag`</a>__: The flag passed to the program.

|   Name   |   Type    |                                                 Description                                                  | Default |
| -------- | --------- | ------------------------------------------------------------------------------------------------------------ | ------- |
| short    | _string_  | Shorthand for this argument, usually one letter.                                                             | -       |
| boolean  | _boolean_ | Whether the flag is a boolean and does not require a value.                                                  | `false` |
| number   | _boolean_ | Specifies whether the flag should be parsed as a number.                                                     | `false` |
| command  | _boolean_ | If set to true, the value is read from the first argument passed to the CLI command (e.g., `$ cli command`). | `false` |
| multiple | _boolean_ | When using the `command` property, will parse the commands as an array.                                      | `false` |

## Copyright

(c) [Art Deco][1] 2019

[1]: https://artd.eco
